@@ -1,7 +1,7 @@
 """
 transaction_set.py
 
-Defines the Health Care Claims Status 276 005010X212 transaction set model.
+Defines the Health Care Claims Status 277 005010X212 transaction set model.
 """
 from linuxforhealth.x12.models import X12SegmentGroup
 from .loops import Header, Footer, Loop2000A
@@ -10,9 +10,9 @@ from pydantic import Field, root_validator
 from linuxforhealth.x12.validators import validate_segment_count
 
 
-class HealthCareClaimsStatusRequest(X12SegmentGroup):
+class HealthCareClaimsStatusResponse(X12SegmentGroup):
     """
-    The Health Care Claims Status transaction model - 276
+    The Health Care Claims Status Response transaction model - 277
     """
 
     header: Header
